//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2018 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package main

import (
	"errors"
	"os"

	"gitlab.servus.at/autoradio/tank/importer"
	"gitlab.servus.at/autoradio/tank/store"
	"gopkg.in/yaml.v2"
)

type Config struct {
	Store    store.Config    `json:"store" yaml:"store" toml:"store"`
	Importer importer.Config `json:"importer" yaml:"importer" toml:"importer"`
}

func ReadConfig(configfile string) (conf *Config, err error) {
	var f *os.File
	if f, err = os.Open(configfile); err != nil {
		err = errors.New("error opening config file(" + configfile + "): " + err.Error())
		return
	}
	defer f.Close()

	conf = &Config{}
	decoder := yaml.NewDecoder(f)
	decoder.SetStrict(true)
	if err = decoder.Decode(conf); err != nil {
		err = errors.New("error opening config file(" + configfile + "): " + err.Error())
		return
	}
	infoLog.Printf("successfully read config file (%s)", configfile)
	return
}
