//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2018 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package importer

import (
	"errors"
)

type ConverterType int

const (
	ConvFFmpeg ConverterType = iota
	ConvFFmpegBS1770
)

func (c *ConverterType) String() string {
	switch *c {
	case ConvFFmpeg:
		return "ffmpeg"
	case ConvFFmpegBS1770:
		return "ffmpeg+bs1770"
	}
	return "unknown"
}

func (c *ConverterType) fromString(str string) error {
	switch str {
	case "ffmpeg":
		*c = ConvFFmpeg
	case "ffmpeg+bs1770":
		*c = ConvFFmpegBS1770
	default:
		return errors.New("invalid converter: '" + str + "'")
	}
	return nil
}

func (c *ConverterType) MarshalText() (data []byte, err error) {
	data = []byte(c.String())
	return
}

func (c *ConverterType) UnmarshalText(data []byte) (err error) {
	return c.fromString(string(data))
}

type Config struct {
	TempPath  string        `json:"temp-path" yaml:"temp-path" toml:"temp-path"`
	Workers   int           `json:"workers" yaml:"workers" toml:"workers"`
	Backlog   uint          `json:"backlog" yaml:"backlog" toml:"backlog"`
	Converter ConverterType `json:"converter" yaml:"converter" toml:"converter"`
}
