//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2018 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package importer

import (
	"io"
)

type converter interface {
	io.WriteCloser
	GetResult() (loudnessCorr float64, log []string, err error)
}

func newConverter(job *Job) converter {
	switch job.im.conf.Converter {
	case ConvFFmpeg:
		return newFFmpegConverter(job)
	case ConvFFmpegBS1770:
		return newFFmpegBS1770Converter(job)
	}
	panic("invalid fetch converter")
}

//******* FFmpeg

type ffmpegConverter struct {
	job *Job
}

func newFFmpegConverter(job *Job) *ffmpegConverter {
	return &ffmpegConverter{job}
}

func (c *ffmpegConverter) Write(p []byte) (n int, err error) {
	return 0, ErrNotImplemented
}

func (c *ffmpegConverter) Close() (err error) {
	return ErrNotImplemented
}

func (c *ffmpegConverter) GetResult() (loudnessCorr float64, log []string, err error) {
	return 0, []string{"ERROR: not implemented"}, ErrNotImplemented
}

//******* FFmpeg+BS1770

type ffmpegBS1770Converter struct {
	job *Job
}

func newFFmpegBS1770Converter(job *Job) *ffmpegBS1770Converter {
	return &ffmpegBS1770Converter{job}
}

func (c *ffmpegBS1770Converter) Write(p []byte) (n int, err error) {
	return 0, ErrNotImplemented
}

func (c *ffmpegBS1770Converter) Close() (err error) {
	return ErrNotImplemented
}

func (c *ffmpegBS1770Converter) GetResult() (loudnessCorr float64, log []string, err error) {
	return 0, []string{"ERROR: not implemented"}, ErrNotImplemented
}
